@@ -1,8 +1,9 @@
+use console::Term;
 use core::time;
+use indicatif::{ProgressBar, ProgressStyle};
+use notify_rust::Notification;
 use std::thread;
 
-use indicatif::ProgressBar;
-
 use crate::config::TomatoConfig;
 
 pub struct Session {
@@ -55,13 +56,17 @@ impl Session {
             match self.state {
                 State::None => {}
                 State::Working => {
-                    process_state(self.config.work_time, "Working..");
+                    notify(&format!("🍅 Start work time #{}", self.work_count + 1));
+                    process_state(self.config.work_time, "Working...");
                     self.work_count += 1;
                 }
-
-                State::LongBreak => process_state(self.config.long_break_time, "Long Breaking.."),
                 State::ShortBreak => {
-                    process_state(self.config.short_break_time, "Short Breaking..")
+                    notify("🍅 Start short break time");
+                    process_state(self.config.short_break_time, "Short Breaking...")
+                }
+                State::LongBreak => {
+                    notify("🍅 Start long break time");
+                    process_state(self.config.long_break_time, "Long Breaking...");
                 }
             }
             self.next();
@@ -69,12 +74,28 @@ impl Session {
     }
 }
 
+fn notify(message: &str) {
+    Notification::new()
+        .body(message)
+        .sound_name("Ping")
+        .show()
+        .unwrap();
+}
+
 fn process_state(duration: u64, state_msg: &str) {
+    let term = Term::stdout();
     let duration_second = duration * 60;
 
+    term.clear_screen().unwrap();
+    term.write_line(&format!("Tomato: {}", state_msg)).unwrap();
+
     let progress = ProgressBar::new(duration_second);
+    progress.set_style(
+        ProgressStyle::default_bar()
+            .template("{spinner:.green} [{elapsed_precise}] [{wide_bar:.cyan/blue}]"),
+    );
+    progress.inc(0);
 
-    println!("{}", state_msg);
     for _i in 0..duration_second {
         thread::sleep(time::Duration::from_secs(1));
         progress.inc(1);
@@ -88,20 +109,19 @@ mod tests {
     use super::*;
 
     #[test]
-    fn next_state_working_after_long_break() {
+    fn next_state_none_should_be_working() {
         let config = TomatoConfig::new(25, 5, 15);
-        let mut session = Session {
+        let session = Session {
             work_count: 0,
-            state: State::Working,
+            state: State::None,
             config,
         };
-        session.work_count = 4;
         let next = session.next_state();
-        assert_eq!(next, State::LongBreak);
+        assert_eq!(next, State::Working);
     }
 
     #[test]
-    fn next_state_working_after_short_break() {
+    fn next_to_working_should_be_short_break() {
         let config = TomatoConfig::new(25, 5, 15);
         let session = Session {
             work_count: 0,
@@ -111,4 +131,40 @@ mod tests {
         let next = session.next_state();
         assert_eq!(next, State::ShortBreak);
     }
+
+    #[test]
+    fn next_to_repeating_working_should_be_long_break() {
+        let config = TomatoConfig::new(25, 5, 15);
+        let session = Session {
+            work_count: 4,
+            state: State::Working,
+            config,
+        };
+        let next = session.next_state();
+        assert_eq!(next, State::LongBreak);
+    }
+
+    #[test]
+    fn next_state_short_break_should_be_working() {
+        let config = TomatoConfig::new(25, 5, 15);
+        let session = Session {
+            work_count: 0,
+            state: State::ShortBreak,
+            config,
+        };
+        let next = session.next_state();
+        assert_eq!(next, State::Working);
+    }
+
+    #[test]
+    fn next_state_long_break_should_be_working() {
+        let config = TomatoConfig::new(25, 5, 15);
+        let session = Session {
+            work_count: 0,
+            state: State::LongBreak,
+            config,
+        };
+        let next = session.next_state();
+        assert_eq!(next, State::Working);
+    }
 }
